Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(777)

Unified Diff: content/common/mojo/service_registry_impl.h

Issue 358743002: Mojo: Remove InterfaceProvider. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: address comments Created 6 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/common/BUILD.gn ('k') | content/common/mojo/service_registry_impl.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/common/mojo/service_registry_impl.h
diff --git a/content/common/mojo/service_registry_impl.h b/content/common/mojo/service_registry_impl.h
index 8e60b3756b7299faf24f063a059418a8c51d55cd..c0dce522e368e912bd9f9ef5d40d040bf86ad415 100644
--- a/content/common/mojo/service_registry_impl.h
+++ b/content/common/mojo/service_registry_impl.h
@@ -14,13 +14,12 @@
#include "content/public/common/service_registry.h"
#include "mojo/public/cpp/bindings/interface_impl.h"
#include "mojo/public/cpp/system/core.h"
-#include "mojo/public/interfaces/interface_provider/interface_provider.mojom.h"
+#include "mojo/public/interfaces/service_provider/service_provider.mojom.h"
namespace content {
-class ServiceRegistryImpl
- : public ServiceRegistry,
- public mojo::InterfaceImpl<mojo::IInterfaceProvider> {
+class ServiceRegistryImpl : public ServiceRegistry,
+ public mojo::InterfaceImpl<mojo::ServiceProvider> {
public:
ServiceRegistryImpl();
explicit ServiceRegistryImpl(mojo::ScopedMessagePipeHandle handle);
@@ -28,7 +27,7 @@ class ServiceRegistryImpl
// Binds to a remote ServiceProvider. This will expose added services to the
// remote ServiceProvider with the corresponding handle and enable
// GetInterface to provide access to services exposed by the remote
// ServiceProvider.
void BindRemoteServiceProvider(mojo::ScopedMessagePipeHandle handle);
@@ -38,13 +37,13 @@ class ServiceRegistryImpl
const base::Callback<void(mojo::ScopedMessagePipeHandle)> service_factory)
OVERRIDE;
virtual void RemoveService(const std::string& service_name) OVERRIDE;
- virtual void GetRemoteInterface(
+ virtual void ConnectToRemoteService(
const base::StringPiece& service_name,
mojo::ScopedMessagePipeHandle handle) OVERRIDE;
private:
- // mojo::InterfaceImpl<mojo::IInterfaceProvider> overrides.
- virtual void GetInterface(
+ // mojo::InterfaceImpl<mojo::ServiceProvider> overrides.
+ virtual void ConnectToService(
const mojo::String& name,
mojo::ScopedMessagePipeHandle client_handle) OVERRIDE;
virtual void OnConnectionError() OVERRIDE;
@@ -28,7 +27,7 @@ class ServiceRegistryImpl
// Binds to a remote ServiceProvider. This will expose added services to the
// remote ServiceProvider with the corresponding handle and enable
- // GetInterface to provide access to services exposed by the remote
+ // ConnectToRemoteService to provide access to services exposed by the remote
// ServiceProvider.
void BindRemoteServiceProvider(mojo::ScopedMessagePipeHandle handle);
« no previous file with comments | « content/common/BUILD.gn ('k') | content/common/mojo/service_registry_impl.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698